# s3contents Change Log

## [Unreleased]

## 0.4
- Drop support for Python 2, only Python >=3.5 is supported now
- Updated dependencies

## 0.3
- Better error message on AccessDenied errors

## 0.1.12
- Parameter for S3/AWS Session token

## 0.1.11
- Support IPython 7

## 0.1.0
- Initial release
